@@ -1,6 +1,7 @@
 /* init.h
  *
  * Copyright (C) 2005-2006 The gtksourceviewmm development team
+ * Copyright (C) 2010 Krzesimir Nowak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -18,18 +19,19 @@
  */
 
 #include "init.h"
-namespace gtksourceview
+namespace Gsv
 {
 
 void
 init ()
 {
-    static bool s_init = false ;
-    if (!s_init) {
-        Glib::init () ;
-        gtksourceview::wrap_init () ;
-        s_init = true ;
-    }
+  static bool s_init = false ;
+  if (!s_init)
+  {
+    Gtk::Main::init_gtkmm_internals() ;
+    Gsv::wrap_init () ;
+    s_init = true ;
+  }
 }
 
-}
+} // namespace Gsv
